<?php

/**
 * @author Targetbay Team
 * @copyright Copyright (c) 2016 Targetbay
 * @package Targetbay_Tracking
 */

namespace Targetbay\Tracking\Model;

use Magento\Catalog\Model\ProductFactory;
use Magento\Catalog\Model\ResourceModel\Product\CollectionFactory;
use Targetbay\Tracking\Api\ProductInterface;
use Targetbay\Tracking\Helper\Data;

/**
 * Defines the implementation class of the ProductInterface.
 */
class Product implements ProductInterface
{
    /**
     * @var Data
     */
    public $trackingHelper;

    /**
     * @var CollectionFactory
     */
    private $productCollection;

    /**
     * @var ProductFactory
     */
    private $productFactory;

    /**
     * @var Data
     */
    private $_trackingHelper;

    /**
     * @param Data $trackingHelper
     * @param CollectionFactory $productCollection
     * @param ProductFactory $productFactory
     */
    public function __construct(
        Data $trackingHelper,
        CollectionFactory $productCollection,
        ProductFactory $productFactory
    ) {
        $this->_trackingHelper = $trackingHelper;
        $this->productCollection = $productCollection;
        $this->productFactory = $productFactory;
    }

    /**
     * Get the total count of Products
     *
     * @return product count
     */
    public function getList()
    {

        $products = $this->productCollection->create()->addAttributeToSelect('*')->load()->toArray();

        foreach ($products as $id => $data) {
            $product = $this->productFactory->create()->load($id);
            $categoryIds = $product->getCategoryIds();
            $products[$id]['category_id'] = implode(',', $categoryIds);
            $products[$id]['category_name'] = $this->_trackingHelper->getProductCategoryName($product);
        }

        return $products;
    }
}
